<?php
// Import framework stuff
use Org\Mxchange\CoreFramework\Bootstrap\FrameworkBootstrap;
use Org\Mxchange\CoreFramework\EntryPoint\ApplicationEntryPoint;

/**
 * General configuration. Do not touch this file! If you need different settings
 * create a config-local.php in this directory at and set your changed
 * configuration entries there.
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2020 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

// Get a new configuration instance
$cfg = FrameworkBootstrap::getConfigurationInstance();

// CFG: ROOT-BASE-PATH
$cfg->setConfigEntry('root_base_path', ApplicationEntryPoint::getRootPath() . DIRECTORY_SEPARATOR);

// CFG: CORE-BASE-PATH
$cfg->setConfigEntry('framework_base_path', ApplicationEntryPoint::detectFrameworkPath());

// CFG: BASE-URL
$cfg->setConfigEntry('base_url', FrameworkBootstrap::detectBaseUrl());

// CFG: DATABASE-TYPE
$cfg->setConfigEntry('database_type', 'local_file_database');

// CFG: LOCAL-DATABASE-PATH
$cfg->setConfigEntry('local_database_path', $cfg->getConfigEntry('root_base_path') . 'db/');

// Default timezone
FrameworkBootstrap::setDefaultTimezone('Europe/Berlin');

// CFG: CLASS-PREFIX
$cfg->setConfigEntry('class_prefix', 'class_');

// CFG: CLASS-SUFFIX
$cfg->setConfigEntry('class_suffix', '.php');

// CFG: RAW-TEMPLATE-EXTENSION
$cfg->setConfigEntry('raw_template_extension', '.tpl');

// CFG: CODE-TEMPLATE-EXTENSION
$cfg->setConfigEntry('code_template_extension', '.ctp');

// CFG: SELECTOR-PATH
$cfg->setConfigEntry('selector_path', 'selector');

// CFG: TEMPLATE-BASE-PATH
$cfg->setConfigEntry('tpl_base_path', 'templates/');

// CFG: LANGUAGE-BASE-PATH
$cfg->setConfigEntry('language_base_path', 'language/');

// CFG: COMPRESSOR-BASE-PATH
$cfg->setConfigEntry('compressor_base_path', 'main/classes/compressor/');

// CFG: APPLICATION-BASE-PATH
$cfg->setConfigEntry('application_base_path', $cfg->getConfigEntry('root_base_path') . 'application/');

// CFG: COMPILE-OUTPUT-PATH
$cfg->setConfigEntry('compile_output_path', 'templates/_compiled/');

// CFG: HTML-TEMPLATE-CLASS
$cfg->setConfigEntry('html_template_class', 'Org\Mxchange\CoreFramework\Template\Engine\HtmlTemplateEngine');

// CFG: DECO-XML-REWRITER-TEMPLATE-CLASS
$cfg->setConfigEntry('deco_xml_rewriter_template_class', 'Org\Mxchange\CoreFramework\Template\Xml\XmlRewriterTemplateDecorator');

// CFG: DEBUG-HTML-CLASS
$cfg->setConfigEntry('debug_html_class', 'Org\Mxchange\CoreFramework\Output\Debug\DebugWebOutput');

// CFG: DEBUG-CONSOLE-CLASS
$cfg->setConfigEntry('debug_console_class', 'Org\Mxchange\CoreFramework\Debug\Output\DebugConsoleOutput');

// CFG: DEFAULT-LANGUAGE
$cfg->setConfigEntry('default_lang', 'de'); // A two-char language string: de for german, en for english and so on

// CFG: HTML-TEMPLATE-TYPE
$cfg->setConfigEntry('html_template_type', 'html');

// CFG: EMAIL-TEMPLATE-TYPE
$cfg->setConfigEntry('email_template_type', 'emails');

// CFG: CODE-HTML-TEMPLATE-TYPE
$cfg->setConfigEntry('code_html_template_type', 'code');

// CFG: CODE-CONSOLE-TEMPLATE-TYPE
$cfg->setConfigEntry('code_console_template_type', 'xml');

// CFG: IMAGE-TEMPLATE-TYPE
$cfg->setConfigEntry('image_template_type', 'image');

// CFG: MENU-TEMPLATE-TYPE
$cfg->setConfigEntry('menu_template_type', 'menu');

// CFG: OUTPUT-CLASS
$cfg->setConfigEntry('output_class', 'Org\Mxchange\CoreFramework\Output\WebOutput');

// CFG: LANGUAGE-SYSTEM-CLASS
$cfg->setConfigEntry('language_system_class', 'Org\Mxchange\CoreFramework\Localization\LanguageSystem');

// CFG: SELECTOR-TEMPLATE-PREFIX
$cfg->setConfigEntry('tpl_selector_prefix', 'selector');

// CFG: WEB-CONTENT-TYPE
$cfg->setConfigEntry('web_content_type', 'text/html');

// CFG: VALID-TEMPLATE-VARIABLE
$cfg->setConfigEntry('tpl_valid_var', 'content');

// CFG: META-AUTHOR
$cfg->setConfigEntry('meta_author', 'Your-name-here');

// CFG: META-PUBLISHER
$cfg->setConfigEntry('meta_publisher', 'Your-name-here');

// CFG: META-KEYWORDS
$cfg->setConfigEntry('meta_keywords', 'test,test,test');

// CFG: META-DESCRIPTION
$cfg->setConfigEntry('meta_description', 'A description for your website');

// CFG: SELECTOR-MAIN-TEMPLATE
$cfg->setConfigEntry('selector_main_tpl', 'selector_main');

// CFG: SELECTOR-APPS-TEMPLATE
$cfg->setConfigEntry('selector_apps_tpl', 'selector_apps');

// CFG: SELECTOR-NAME
$cfg->setConfigEntry('selector_name', 'selector');

// CFG: DEFAULT-APPLICATION
$cfg->setConfigEntry('default_application', 'selector');

// CFG: VERBOSE-LEVEL
$cfg->setConfigEntry('verbose_level', 0);

// CFG: CACHE-CLASS
$cfg->setConfigEntry('cache_class', 'Org\Mxchange\CoreFramework\Cache\Memory\MemoryCache');

// CFG: SEARCH-CRITERIA-CLASS
$cfg->setConfigEntry('search_criteria_class', 'Org\Mxchange\CoreFramework\Criteria\Search\SearchCriteria');

// CFG: DATASET-CRITERIA-CLASS
$cfg->setConfigEntry('dataset_criteria_class', 'Org\Mxchange\CoreFramework\Criteria\DataSet\DataSetCriteria');

// CFG: UPDATE-CRITERIA-CLASS
$cfg->setConfigEntry('update_criteria_class', 'Org\Mxchange\CoreFramework\Criteria\Update\UpdateCriteria');

// CFG: FILE-IO-CLASS
$cfg->setConfigEntry('file_io_class', 'Org\Mxchange\CoreFramework\Handler\Filesystem\FileIoHandler');

// CFG: DATABASE-RESULT-CLASS
$cfg->setConfigEntry('database_result_class', 'Org\Mxchange\CoreFramework\Result\Database\CachedDatabaseResult');

// CFG: FILTER-CHAIN-CLASS
$cfg->setConfigEntry('filter_chain_class', 'Org\Mxchange\CoreFramework\Chain\Filter\FilterChain');

// CFG: FILE-INPUT-CLASS
$cfg->setConfigEntry('file_input_class', 'Org\Mxchange\CoreFramework\Stream\Filesystem\FileIoStream');

// CFG: FILE-OUTPUT-CLASS
$cfg->setConfigEntry('file_output_class', 'Org\Mxchange\CoreFramework\Stream\Filesystem\FileIoStream');

// CFG: EMAIL-VALIDATOR-FILTER-CLASS
$cfg->setConfigEntry('email_validator_filter_class', 'Org\Mxchange\CoreFramework\Filter\Validator\Email\EmailValidatorFilter');

// CFG: USERNAME-VALIDATOR-FILTER-CLASS
$cfg->setConfigEntry('username_validator_filter_class', 'Org\Mxchange\CoreFramework\Filter\Validator\Username\UserNameValidatorFilter');

// CFG: USERNAME-IS-GUEST-FILTER-CLASS
$cfg->setConfigEntry('username_is_guest_filter_class', 'Org\Mxchange\CoreFramework\Filter\User\Username\UserNameIsGuestFilter');

// CFG: PASSWORD-VALIDATOR-FILTER-CLASS
$cfg->setConfigEntry('password_validator_filter_class', 'Org\Mxchange\CoreFramework\Filter\Validator\Password\PasswordValidatorFilter');

// CFG: RULES-ACCEPTED-FILTER-CLASS
$cfg->setConfigEntry('rules_accepted_filter_class', 'Org\Mxchange\CoreFramework\Filter\RulesCheckbox\RulesAcceptedFilter');

// CFG: USERNAME-VERIFIER-FILTER-CLASS
$cfg->setConfigEntry('username_verifier_filter_class', 'Org\Mxchange\CoreFramework\Filter\Verifier\User\UserNameVerifierFilter');

// CFG: USER-GUEST-VERIFIER-FILTER-CLASS
$cfg->setConfigEntry('user_guest_verifier_filter_class', 'Org\Mxchange\CoreFramework\Filter\Verifier\User\UserGuestVerifierFilter');

// CFG: EMAIL-VERIFIER-FILTER-CLASS
$cfg->setConfigEntry('email_verifier_filter_class', 'Org\Mxchange\CoreFramework\Filter\Verifier\Email\EmailVerifierFilter');

// CFG: PASSWORD-VERIFIER-FILTER-CLASS
$cfg->setConfigEntry('password_verifier_filter_class', 'Org\Mxchange\CoreFramework\Filter\Verifier\Password\PasswordVerifierFilter');

// CFG: PASSWD-GUEST-VERIFIER-FILTER-CLASS
$cfg->setConfigEntry('passwd_guest_verifier_filter_class', 'Org\Mxchange\CoreFramework\Filter\Verifier\User\PasswordGuestVerifierFilter');

// CFG: EMAIL-CHANGE-FILTER-CLASS
$cfg->setConfigEntry('email_change_filter_class', 'Org\Mxchange\CoreFramework\Filter\Change\Email\EmailChangeFilter');

// CFG: PASSWORD-CHANGE-FILTER-CLASS
$cfg->setConfigEntry('password_change_filter_class', 'Org\Mxchange\CoreFramework\Filter\Change\Password\PasswordChangeFilter');

// CFG: ACCOUNT-PASSWORD-FILTER-CLASS
$cfg->setConfigEntry('account_password_filter_class', 'Org\Mxchange\CoreFramework\Filter\Verifier\Password\AccountPasswordVerifierFilter');

// CFG: USER-STATUS-FILTER-CLASS
$cfg->setConfigEntry('user_status_filter_class', 'Org\Mxchange\CoreFramework\Filter\Verifier\User\UserStatusVerifierFilter');

// CFG: USER-UNCONFIRMED-FILTER-CLASS
$cfg->setConfigEntry('user_unconfirmed_filter_class', 'Org\Mxchange\CoreFramework\Filter\Verifier\User\UserUnconfirmedVerifierFilter');

// CFG: CRYPTO-CLASS
$cfg->setConfigEntry('crypto_class', 'Org\Mxchange\CoreFramework\Helper\Crypto\CryptoHelper');

// CFG: RNG-CLASS
$cfg->setConfigEntry('rng_class', 'Org\Mxchange\CoreFramework\Crypto\RandomNumber\RandomNumberGenerator');

// CFG: USER-DB-FRONTEND-CLASS
$cfg->setConfigEntry('user_db_frontend_class', 'Org\Mxchange\CoreFramework\Database\Frontend\User\UserDatabaseFrontend');

// CFG: NEWS-DB-FRONTEND-CLASS
$cfg->setConfigEntry('news_db_frontend_class', 'Org\Mxchange\CoreFramework\Database\Frontend\News\NewsDatabaseFrontend');

// CFG: HTML-CMD-RESOLVER-CLASS
$cfg->setConfigEntry('html_cmd_resolver_class', 'Org\Mxchange\CoreFramework\Resolver\Command\HtmlCommandResolver');

// CFG: HTML-CMD-LOGIN-RESOLVER-CLASS
$cfg->setConfigEntry('html_cmd_login_resolver_class', 'Org\Mxchange\CoreFramework\Resolver\Command\HtmlCommandResolver');

// CFG: IMAGE-CMD-RESOLVER-CLASS
$cfg->setConfigEntry('image_cmd_resolver_class', 'Org\Mxchange\CoreFramework\Resolver\Command\ImageCommandResolver');

// CFG: IMAGE-CMD-CODE-CAPTCHA-RESOLVER-CLASS
$cfg->setConfigEntry('image_cmd_code_captcha_resolver_class', 'Org\Mxchange\CoreFramework\Resolver\Command\ImageCommandResolver');

// CFG: MAILER-CLASS
$cfg->setConfigEntry('mailer_class', 'Org\Mxchange\CoreFramework\Mailer\Debug\DebugMailer');

// CFG: XML-PARSER-CLASS
$cfg->setConfigEntry('xml_parser_class', 'Org\Mxchange\CoreFramework\Parser\Xml\XmlParser');

// CFG: DECO-COMPACTING-XML-PARSER-CLASS
$cfg->setConfigEntry('deco_compacting_xml_parser_class', 'Org\Mxchange\CoreFramework\Parser\Xml\XmlCompactorDecorator');

// CFG: MATH-PRIME
$cfg->setConfigEntry('math_prime', 591623);

// CFG: DATE-KEY
$cfg->setConfigEntry('date_key', date('d-m-Y (l-F-T)', time()));

// CFG: SALT-LENGTH
$cfg->setConfigEntry('salt_length', 10);

// CFG: RND-STR-LENGTH
$cfg->setConfigEntry('rnd_str_length', 128);

// CFG: HASH-EXTRA-MASK
$cfg->setConfigEntry('hash_extra_mask', '%1s:%2s:%3s'); // 1=salt, 2=extra salt, 3=plain password/string

// CFG: HASH-NORMAL-MASK
$cfg->setConfigEntry('hash_normal_mask', '%1s:%2s'); // 1=salt, 2=plain password/string

// CFG: IS-SINGLE-SERVER
$cfg->setConfigEntry('is_single_server', 'Y');

// CFG: POST-REGISTRATION-CLASS
$cfg->setConfigEntry('post_registration_class', 'Org\Mxchange\CoreFramework\Action\PostRegistration\Login\LoginAfterRegistrationAction');

// CFG: USER-CLASS
$cfg->setConfigEntry('user_class', 'Org\Mxchange\CoreFramework\User\Login\Member');

// CFG: GUEST-CLASS
$cfg->setConfigEntry('guest_class', 'Org\Mxchange\CoreFramework\User\Guest\Guest');

// CFG: COOKIE-EXPIRE
$cfg->setConfigEntry('cookie_expire', (60*60*2)); // Two hours!

// CFG: COOKIE-PATH
$cfg->setConfigEntry('cookie_path', FrameworkBootstrap::detectScriptPath() . DIRECTORY_SEPARATOR);

// CFG: COOKIE-DOMAIN
$cfg->setConfigEntry('cookie_domain', FrameworkBootstrap::detectDomain()); // Is mostly the same...

// CFG: COOKIE-SSL
$cfg->setConfigEntry('cookie_ssl', FrameworkBootstrap::isHttpSecured());

// CFG: CRYPT-FIXED-SALT
$cfg->setConfigEntry('crypt_fixed_salt', 'N');

// CFG: DB-UPDATE-PRIMARY-FORCED
$cfg->setConfigEntry('db_update_primary_forced', 'Y');

// CFG: GERMAN-DATE-TIME
$cfg->setConfigEntry('german_date_time', "%3\$s.%2\$s.%1\$s, %4\$s:%5\$s:%6\$s");

// CFG: PRODUCT-INSTALL-MODE
$cfg->setConfigEntry('product_install_mode', 'debug');

// CFG: DECIMALS
$cfg->setConfigEntry('decimals', 3);

// CFG: MENU-STACKER-CLASS
$cfg->setConfigEntry('menu_stacker_class', 'Org\Mxchange\CoreFramework\Stacker\FiLoStacker');

// CFG: STACKER-GENERIC-MAX-SIZE
$cfg->setConfigEntry('stacker_generic_max_size', 100);

// CFG: STACKER-CURRENT-NODE-MAX-SIZE
$cfg->setConfigEntry('stacker_current_node_max_size', 20);

// CFG: LOCAL-FILE-DATABASE-CLASS
$cfg->setConfigEntry('local_file_database_class', 'Org\Mxchange\CoreFramework\Database\Backend\Lfdb\CachedLocalFileDatabase');

// CFG: COMPRESSOR-CHANNEL-CLASS
$cfg->setConfigEntry('compressor_channel_class', 'Org\Mxchange\CoreFramework\Middleware\Compressor\CompressorChannel');

// CFG: DEBUG-HTML-OUTPUT-TIMINGS
$cfg->setConfigEntry('debug_html_output_timings', 'N');

// CFG: DEBUG-CONSOLE-OUTPUT-TIMINGS
$cfg->setConfigEntry('debug_console_output_timings', 'Y');

// CFG: PROXY-HOST
$cfg->setConfigEntry('proxy_host', '');

// CFG: PROXY-PORT
$cfg->setConfigEntry('proxy_port', '');

// CFG: PROXY-USERNAME
$cfg->setConfigEntry('proxy_username', '');

// CFG: PROXY-PASSWORD
$cfg->setConfigEntry('proxy_password', '');

// CFG: PROXY-CONNECT-METHOD
$cfg->setConfigEntry('proxy_connect_method', 'Y');

// CFG: HOSTNAME-FILE
$cfg->setConfigEntry('hostname_file', '/etc/hostname');

// CFG: DATABASE-CACHE-ENABLED
$cfg->setConfigEntry('database_cache_enabled', false);

// CFG: DIRECTORY-CLASS
$cfg->setConfigEntry('directory_class', 'Org\Mxchange\CoreFramework\Filesytem\Pointer\FrameworkDirectoryPointer');

// CFG: FILE-RAW-INPUT-CLASS
$cfg->setConfigEntry('file_raw_input_class', 'Org\Mxchange\CoreFramework\Filesystem\Pointer\Input\FrameworkRawFileInputPointer');

// CFG: FILE-RAW-OUTPUT-CLASS
$cfg->setConfigEntry('file_raw_output_class', 'Org\Mxchange\CoreFramework\Filesystem\Pointer\Output\FrameworkRawFileOutputPointer');

// CFG: FILE-RAW-INPUT-OUTPUT-CLASS
$cfg->setConfigEntry('file_raw_input_output_class', 'Org\Mxchange\CoreFramework\Filesystem\Pointer\FrameworkFileInputOutputPointer');

// CFG: TEXT-FILE-INPUT-CLASS
$cfg->setConfigEntry('text_file_input_class', 'Org\Mxchange\CoreFramework\Filesystem\Pointer\Input\FrameworkTextFileInputPointer');

// CFG: CSV-INPUT-FILE-CLASS
$cfg->setConfigEntry('csv_input_file_class', 'Org\Mxchange\CoreFramework\Filesystem\Input\Csv\CsvInputFile');

// CFG: FILE-ITERATOR-CLASS
$cfg->setConfigEntry('file_iterator_class', 'Org\Mxchange\CoreFramework\Iterator\File\FileIterator');

// CFG: FILE-STACK-PRE-ALLOCATE-ENABLED
$cfg->setConfigEntry('file_stack_pre_allocate_enabled', 'Y');

// CFG: FILE-STACK-PRE-ALLOCATE-COUNT
$cfg->setConfigEntry('file_stack_pre_allocate_count', 10000);

// CFG: INDEX-INDEX-CLASS
$cfg->setConfigEntry('file_stack_index_class', 'Org\Mxchange\CoreFramework\Index\Stack\FileStackIndex');

// CFG: INDEX-PRE-ALLOCATE-ENABLED
$cfg->setConfigEntry('index_pre_allocate_enabled', 'Y');

// CFG: INDEX-PRE-ALLOCATE-COUNT
$cfg->setConfigEntry('index_pre_allocate_count', 10000);

// CFG: STACK-FILE-CLASS
$cfg->setConfigEntry('stack_file_class', 'Org\Mxchange\CoreFramework\Filesystem\Stack\StackFile');

// CFG: INDEX-FILE-CLASS
$cfg->setConfigEntry('index_file_class', 'Org\Mxchange\CoreFramework\Filesystem\Index\IndexFile');

// CFG: TASK-HANDLER-CLASS
$cfg->setConfigEntry('task_handler_class', 'Org\Mxchange\CoreFramework\Handler\Task\TaskHandler');

// CFG: TASK-LIST-CLASS
$cfg->setConfigEntry('task_list_class', 'Org\Mxchange\CoreFramework\Lists\Task\TaskList');

// CFG: LIST-GROUP-CLASS
$cfg->setConfigEntry('list_group_class', 'Org\Mxchange\CoreFramework\Lists\Group\ListGroupList');

// CFG: DEFAULT-ITERATOR-CLASS
$cfg->setConfigEntry('default_iterator_class', 'Org\Mxchange\CoreFramework\Iterator\DefaultIterator');

// CFG: IDLE-TASK-CLASS
$cfg->setConfigEntry('idle_task_class', 'Org\Mxchange\CoreFramework\Task\IdleLoop\IdleLoopTask');

// CFG: TASK-IDLE-LOOP-STARTUP-DELAY
$cfg->setConfigEntry('task_idle_loop_startup_delay', 0);

// CFG: TASK-IDLE-LOOP-INTERVAL-DELAY
$cfg->setConfigEntry('task_idle_loop_interval_delay', 0);

// CFG: TASK-IDLE-LOOP-MAX-RUNS
$cfg->setConfigEntry('task_idle_loop_max_runs', 0);

// CFG: IDLE-LOOP-TIME (5 milli seconds)
$cfg->setConfigEntry('idle_loop_time', 5);

// CFG: DEFAULT-IMAGE-COMMAND
$cfg->setConfigEntry('default_image_command', 'build');

// CFG: DEFAULT-IMAGE-CONTROLLER
$cfg->setConfigEntry('default_image_controller', 'build');

// CFG: MENU-TEMPLATE-CLASS
$cfg->setConfigEntry('menu_template_class', 'Org\Mxchange\CoreFramework\Template\Engine\MenuTemplateEngine');

// CFG: CONSOLE-TEMPLATE-CLASS
$cfg->setConfigEntry('console_template_class', 'Org\Mxchange\CoreFramework\Template\Engine\ConsoleTemplateEngine');

// CFG: MENU-TEMPLATE-EXTENSION
$cfg->setConfigEntry('menu_template_extension', '.xml');

// CFG: FEATURE-FUSE-CLASS
$cfg->setConfigEntry('feature_fuse_class', 'Org\Mxchange\CoreFramework\Feature\Fuse\FuseFeature');

// CFG: TEMP-FILE-PATH
$cfg->setConfigEntry('temp_file_path', sys_get_temp_dir());

// CFG: IPC-SOCKET-FILE-NAME
$cfg->setConfigEntry('ipc_socket_file_name', 'php_ipc_socket');

// CFG: EXTENSION-SCRYPT-LOADED (By default scrypt is assumed absent and later tested being there)
$cfg->setConfigEntry('extension_scrypt_loaded', false);

// CFG: EXTENSION-UUID-LOADED (By default uuid is assumed absent and later tested being there)
$cfg->setConfigEntry('extension_uuid_loaded', false);

// CFG: REGISTRY-ITERATOR-CLASS
$cfg->setConfigEntry('registry_iterator_class', 'Org\Mxchange\CoreFramework\Iterator\Registry\RegistryIterator');

// CFG: QUIET-DNS-RESOLVER
$cfg->setConfigEntry('quiet_dns_resolver', false);

// CFG: THOUSANDS-SEPARATOR
$cfg->setConfigEntry('thousands_separator', '.');

// CFG: DECIMALS-SEPARATOR
$cfg->setConfigEntry('decimals_separator', ',');

// CFG: CRYPTO-MCRYPT-STREAM-CLASS
$cfg->setConfigEntry('crypto_mcrypt_stream_class', 'Org\Mxchange\CoreFramework\Stream\Crypto\Mcrypt\McryptStream');

// CFG: CRYPTO-OPENSSL-STREAM-CLASS
$cfg->setConfigEntry('crypto_openssl_stream_class', 'Org\Mxchange\CoreFramework\Stream\Crypto\OpenSsl\OpenSslStream');

// CFG: CRYPTO-NULL-STREAM-CLASS
$cfg->setConfigEntry('crypto_null_stream_class', 'Org\Mxchange\CoreFramework\Stream\Crypto\Null\NullCryptoStream');

// CFG: DEVELOPER-MODE-ENABLED
$cfg->setConfigEntry('developer_mode_enabled', true);
