<?php
// Own namespace
namespace Org\Mxchange\CoreFramework\Stacker\Filesystem;

// Import framework stuff
use Org\Mxchange\CoreFramework\Filesystem\Block\CalculatableBlock;
use Org\Mxchange\CoreFramework\Filesystem\Stack\StackableFile;
use Org\Mxchange\CoreFramework\Registry\Registerable;
use Org\Mxchange\CoreFramework\Stacker\Filesystem\BaseFileStack;

// Import SPL stuff
use \SplFileInfo;

/**
 * A FiFo file-based stack
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2020 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class FiFoFileStack extends BaseFileStack implements StackableFile, CalculatableBlock, Registerable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this class
	 *
	 * @param	$fileInfoInstance	An instance of a SplFileInfo class
	 * @param	$type			Type of this stack (e.g. url_source for URL sources)
	 * @return	$stackInstance	An instance of a StackableFile class
	 */
	public final static function createFiFoFileStack (SplFileInfo $fileInfoInstance, $type) {
		// Get new instance
		$stackInstance = new FiFoFileStack();

		// Init this stack
		$stackInstance->initFileStack($fileInfoInstance, $type);

		// Return the prepared instance
		return $stackInstance;
	}

	/**
	 * Pushs a value on a named stacker
	 *
	 * @param	$stackerName	Name of the stack
	 * @param	$value			Value to push on it
	 * @return	void
	 * @throws	StackerFullException	If the stack is full
	 */
	public function pushNamed (string $stackerName, $value) {
		// Call the protected method
		parent::addValue($stackerName, $value);
	}

	/**
	 * 'Pops' a value from a named stacker and returns it's value
	 *
	 * @param	$stackerName	Name of the stack
	 * @return	$value			Value of the current stack entry
	 * @throws	BadMethodCallException	If the named stacker was not found
	 * @throws	BadMethodCallException	If the named stacker is empty
	 */
	public function popNamed (string $stackerName) {
		// Get the value
		$value = $this->getNamed($stackerName);

		// Call the protected method
		parent::popFirst($stackerName);

		// Return the value
		return $value;
	}

	/**
	 * Get value from named stacker
	 *
	 * @param	$stackerName	Name of the stack
	 * @return	$value			Value of last added value
	 * @throws	BadMethodCallException	If the named stacker was not found
	 * @throws	BadMethodCallException	If the named stacker is empty
	 */
	public function getNamed (string $stackerName) {
		// Call the protected method
		return parent::getFirstValue($stackerName);
	}

	/**
	 * Seeks to given position
	 *
	 * @param	$seekPosition	Seek position in file
	 * @return	$status			Status of this operation
	 */
	public function seek ($seekPosition) {
		$this->partialStub('seekPosition=' . $seekPosition);
	}

	/**
	 * Size of file stack
	 *
	 * @return	$size	Size (in bytes) of file
	 */
	public function size () {
		// Call the iterator instance
		return $this->getIteratorInstance()->size();
	}

}
